==> bootstrap-vue-3-0.0.4.tgz: package/src/components/index.ts <==
import BAccordion from './BAccordion.vue'
import BAccordionItem from './BAccordionItem.vue'
import BAlert from './BAlert.vue'
import BAvatar from './BAvatar/BAvatar.vue'
import BAvatarGroup from './BAvatar/BAvatarGroup.vue'
import BBadge from './BBadge.vue'
import BBreadcrumb from './BBreadcrumb.vue'
import BBreadcrumbItem from './BBreadcrumbItem.vue'
import BButton from './BButton.vue'
import BButtonGroup from './BButtonGroup.vue'
import BButtonToolbar from './BButtonToolbar.vue'
import BCard from './BCard/BCard.vue'
import BCardBody from './BCard/BCardBody.vue'
import BCardFooter from './BCard/BCardFooter.vue'
import BCardGroup from './BCard/BCardGroup.vue'
import BCardHeader from './BCard/BCardHeader.vue'
import BCardImg from './BCard/BCardImg.vue'
import BCardSubTitle from './BCard/BCardSubTitle.vue'
import BCardText from './BCard/BCardText.vue'
import BCardTitle from './BCard/BCardTitle.vue'
import BCarousel from './BCarousel.vue'
import BCarouselSlide from './BCarouselSlide.vue'
import BCloseButton from './BCloseButton.vue'
import BCol from './BCol.vue'
import BCollapse from './BCollapse.vue'
import BContainer from './BContainer.vue'
import BDropdown from './BDropdown.vue'
import BDropdownDivider from './BDropdownDivider.vue'
import BDropdownForm from './BDropdownForm.vue'
import BDropdownGroup from './BDropdownGroup.vue'
import BDropdownHeader from './BDropdownHeader.vue'
import BDropdownItem from './BDropdownItem.vue'
import BDropdownItemButton from './BDropdownItemButton.vue'
import BDropdownText from './BDropdownText.vue'
import BForm from './BForm.vue'
import BFormCheckbox from './BFormCheckbox/BFormCheckbox.vue'
import BFormCheckboxGroup from './BFormCheckbox/BFormCheckboxGroup.vue'
import BFormRadio from './BFormRadio'
import BFormRadioGroup from './BFormRadio/BFormRadioGroup.vue'
import BFormInput from './BFormInput/BFormInput.vue'
import BFormFloatingLabel from './BFormFloatingLabel.vue'
import BFormSelect from './BFormSelect/BFormSelect.vue'
import BFormSelectOption from './BFormSelect/BFormSelectOption.vue'
import BFormSelectOptionGroup from './BFormSelect/BFormSelectOptionGroup.vue'
import BFormText from './BFormText.vue'
import BIcon from './BIcon.vue'
import BImg from './BImg.vue'
import BInputGroup from './BInputGroup.vue'
import BInputGroupText from './BInputGroupText.vue'
import BLink from './BLink.vue'
import BListGroup from './BListGroup.vue'
import BListGroupItem from './BListGroupItem.vue'
import BModal from './BModal.vue'
import BNav from './BNav.vue'
import BNavItem from './BNavItem.vue'
// import BNavItemDropdown from './BNavItemDropdown.vue';
import BOffcanvas from './BOffcanvas.vue'
import BPagination from './BPagination.vue'
import BPopover from './BPopover.vue'
import BProgress from './BProgress.vue'
import BProgressBar from './BProgressBar.vue'
import BRow from './BRow.vue'
import BSpinner from './BSpinner.vue'
import BTable from './BTable/BTable.vue'
import BTabs from './BTabs.vue'
import BTab from './BTab.vue'

export default {
  BAccordion,
  BAccordionItem,
  BAlert,
  BAvatar,
  BAvatarGroup,
  BBadge,
  BBreadcrumb,
  BBreadcrumbItem,
  BButton,
  BButtonGroup,
  BButtonToolbar,
  BCard,
  BCardBody,
  BCardFooter,
  BCardGroup,
  BCardHeader,
  BCardImg,
  BCardSubTitle,
  BCardText,
  BCardTitle,
  BCarousel,
  BCarouselSlide,
  BCloseButton,
  BCol,
  BCollapse,
  BContainer,
  BDropdown,
  BDropdownDivider,
  BDropdownForm,
  BDropdownGroup,
  BDropdownHeader,
  BDropdownItem,
  BDropdownItemButton,
  BDropdownText,
  BForm,
  BFormSelect,
  BFormSelectOption,
  BFormSelectOptionGroup,
  BFormFloatingLabel,
  BFormInput,
  BFormText,
  BIcon,
  BImg,
  BInputGroup,
  BInputGroupText,
  BLink,
  BListGroup,
  BListGroupItem,
  BModal,
  BNav,
  BNavItem,
  // BNavItemDropdown,
  BOffcanvas,
  BPagination,
  BPopover,
  BProgress,
  BProgressBar,
  BRow,
  BSpinner,
  BTable,
  BTabs,
  BTab,
  BFormCheckbox,
  BFormCheckboxGroup,
  BFormRadio,
  BFormRadioGroup,
}

==> bootstrap-vue-3-0.0.5.tgz: package/src/components/index.ts <==
import BAccordion from './BAccordion.vue'
import BAccordionItem from './BAccordionItem.vue'
import BAlert from './BAlert.vue'
import BAvatar from './BAvatar/BAvatar.vue'
import BAvatarGroup from './BAvatar/BAvatarGroup.vue'
import BBadge from './BBadge.vue'
import BBreadcrumb from './BBreadcrumb.vue'
import BBreadcrumbItem from './BBreadcrumbItem.vue'
import BButton from './BButton.vue'
import BButtonGroup from './BButtonGroup.vue'
import BButtonToolbar from './BButtonToolbar.vue'
import BCard from './BCard/BCard.vue'
import BCardBody from './BCard/BCardBody.vue'
import BCardFooter from './BCard/BCardFooter.vue'
import BCardGroup from './BCard/BCardGroup.vue'
import BCardHeader from './BCard/BCardHeader.vue'
import BCardImg from './BCard/BCardImg.vue'
import BCardSubTitle from './BCard/BCardSubTitle.vue'
import BCardText from './BCard/BCardText.vue'
import BCardTitle from './BCard/BCardTitle.vue'
import BCarousel from './BCarousel.vue'
import BCarouselSlide from './BCarouselSlide.vue'
import BCloseButton from './BCloseButton.vue'
import BCol from './BCol.vue'
import BCollapse from './BCollapse.vue'
import BContainer from './BContainer.vue'
import BDropdown from './BDropdown/BDropdown.vue'
import BDropdownDivider from './BDropdown/BDropdownDivider.vue'
import BDropdownForm from './BDropdown/BDropdownForm.vue'
import BDropdownGroup from './BDropdown/BDropdownGroup.vue'
import BDropdownHeader from './BDropdown/BDropdownHeader.vue'
import BDropdownItem from './BDropdown/BDropdownItem.vue'
import BDropdownItemButton from './BDropdown/BDropdownItemButton.vue'
import BDropdownText from './BDropdown/BDropdownText.vue'
import BForm from './BForm/BForm.vue'
import BFormCheckbox from './BFormCheckbox/BFormCheckbox.vue'
import BFormCheckboxGroup from './BFormCheckbox/BFormCheckboxGroup.vue'
import BFormFloatingLabel from './BFormFloatingLabel.vue'
import BFormGroup from './BFormGroup/BFormGroup.vue'
import BFormInput from './BFormInput/BFormInput.vue'
import BFormInvalidFeedback from './BForm/BFormInvalidFeedback.vue'
import BFormRadio from './BFormRadio'
import BFormRadioGroup from './BFormRadio/BFormRadioGroup.vue'
import BFormRow from './BForm/BFormRow.vue'
import BFormSelect from './BFormSelect/BFormSelect.vue'
import BFormSelectOption from './BFormSelect/BFormSelectOption.vue'
import BFormSelectOptionGroup from './BFormSelect/BFormSelectOptionGroup.vue'
import BFormText from './BForm/BFormText.vue'
import BFormTextarea from './BFormTextarea/BFormTextarea.vue'
import BFormValidFeedback from './BForm/BFormValidFeedback.vue'
import BIcon from './BIcon/BIcon.vue'
import BIconstack from './BIcon/BIconstack.vue'
import BImg from './BImg.vue'
import BInputGroup from './BInputGroup/BInputGroup.vue'
import BInputGroupAddon from './BInputGroup/BInputGroupAddon.vue'
import BInputGroupAppend from './BInputGroup/BInputGroupAppend.vue'
import BInputGroupPrepend from './BInputGroup/BInputGroupPrepend.vue'
import BInputGroupText from './BInputGroup/BInputGroupText.vue'
import BLink from './BLink/BLink.vue'
import BListGroup from './BListGroup/BListGroup.vue'
import BListGroupItem from './BListGroup/BListGroupItem.vue'
import BModal from './BModal.vue'
import BNav from './BNav.vue'
import BNavItem from './BNavItem.vue'
// import BNavItemDropdown from './BNavItemDropdown.vue'
import BOffcanvas from './BOffcanvas.vue'
import BOverlay from './BOverlay/BOverlay.vue'
import BPagination from './BPagination/BPagination.vue'
import BPopover from './BPopover.vue'
import BProgress from './BProgress.vue'
import BProgressBar from './BProgressBar.vue'
import BRow from './BRow.vue'
import BSpinner from './BSpinner.vue'
import BTab from './BTabs/BTab.vue'
import BTable from './BTable/BTable.vue'
import BTabs from './BTabs/BTabs.vue'
import BTransition from './BTransition/BTransition.vue'

export default {
  BAccordion,
  BAccordionItem,
  BAlert,
  BAvatar,
  BAvatarGroup,
  BBadge,
  BBreadcrumb,
  BBreadcrumbItem,
  BButton,
  BButtonGroup,
  BButtonToolbar,
  BCard,
  BCardBody,
  BCardFooter,
  BCardGroup,
  BCardHeader,
  BCardImg,
  BCardSubTitle,
  BCardText,
  BCardTitle,
  BCarousel,
  BCarouselSlide,
  BCloseButton,
  BCol,
  BCollapse,
  BContainer,
  BDropdown,
  BDropdownDivider,
  BDropdownForm,
  BDropdownGroup,
  BDropdownHeader,
  BDropdownItem,
  BDropdownItemButton,
  BDropdownText,
  BForm,
  BFormCheckbox,
  BFormCheckboxGroup,
  BFormFloatingLabel,
  BFormGroup,
  BFormInput,
  BFormInvalidFeedback,
  BFormRadio,
  BFormRadioGroup,
  BFormRow,
  BFormSelect,
  BFormSelectOption,
  BFormSelectOptionGroup,
  BFormText,
  BFormTextarea,
  BFormValidFeedback,
  BIcon,
  BIconstack,
  BImg,
  BInputGroup,
  BInputGroupAddon,
  BInputGroupAppend,
  BInputGroupPrepend,
  BInputGroupText,
  BLink,
  BListGroup,
  BListGroupItem,
  BModal,
  BNav,
  BNavItem,
  // BNavItemDropdown,
  BOffcanvas,
  BOverlay,
  BPagination,
  BPopover,
  BProgress,
  BProgressBar,
  BRow,
  BSpinner,
  BTab,
  BTable,
  BTabs,
  BTransition,
}
